@@ -17,11 +17,11 @@ class ApnaExperimentTracker(Tracker):
     
     def __init__(self, 
                 experiment_client_name: str = ExperimentClients.UNLEASH, 
-                experiment_client_conf: 'Configuration' = DefaultUnleashConf(), 
-                sinks: List[Sink] = [MixpanelExperimentSink()]):
+                experiment_client_conf: 'Configuration' = DefaultUnleashConf, 
+                sinks: List[Sink] = [MixpanelExperimentSink]):
         # 1. Initialize experiment_client:
         if self.client is None:
-            self.exp_conf = experiment_client_conf
+            self.exp_conf = experiment_client_conf()
             # TODO: Replace this with ExperimentClientFactory
             # Skipping for now as we are only using unleash as of now.
             self.client = UnleashClient(**self.exp_conf.get_conf())
@@ -30,7 +30,7 @@ class ApnaExperimentTracker(Tracker):
             logging.info(f'ApnaExperimentTracker and UnleashClient initialized!')
             
         # 2. Initialize Sinks:        
-        self.sinks = sinks
+        self.sinks = [sink() for sink in sinks]
         
     def is_enabled(self, feature_name: str, context: Dict[str, str], track: bool = False) -> bool:
         """This method returns by calling `is_enabled` of the unleash client.
